@@ -1,11 +1,11 @@
 package MooseX::ExpiredAttribute;
 
-use Moose ();
+use Moose 2.1204 ();
 
 use MooseX::ExpiredAttribute::Role::Meta::Attribute;
 use MooseX::ExpiredAttribute::Role::Object;
 
-$MooseX::ExpiredAttribute::VERSION = 0.022;
+$MooseX::ExpiredAttribute::VERSION = 0.023;
 
 1;
 
